"""Command line tools translated using Google、Youdao and i18ns.com"""
__all__ = 'mkTranslator',
__version__ = '1.5.3'


from mkTranslation.translator  import mkTranslator
from mkTranslation.constants import LANGCODES, LANGUAGES